Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(648)

Unified Diff: content/browser/permissions/permission_service_context.h

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/permissions/permission_service_context.h
diff --git a/content/browser/permissions/permission_service_context.h b/content/browser/permissions/permission_service_context.h
index 0534ae1b61dfb9132460fffed09e5d343d2fe926..4bc1fa6018e22b1c7936f81cc340a6be94eb6bb2 100644
--- a/content/browser/permissions/permission_service_context.h
+++ b/content/browser/permissions/permission_service_context.h
@@ -12,24 +12,28 @@
namespace content {
+namespace mojom {
class PermissionService;
+}
+
class PermissionServiceImpl;
class RenderFrameHost;
class RenderProcessHost;
// Provides information to a PermissionService. It is used by the
// PermissionService to handle request permission UI.
// There is one PermissionServiceContext per RenderFrameHost/RenderProcessHost
// which owns it. It then owns all PermissionService associated to their owner.
class PermissionServiceContext : public WebContentsObserver {
public:
explicit PermissionServiceContext(RenderFrameHost* render_frame_host);
explicit PermissionServiceContext(RenderProcessHost* render_process_host);
~PermissionServiceContext() override;
- void CreateService(mojo::InterfaceRequest<PermissionService> request);
+ void CreateService(mojo::InterfaceRequest<mojom::PermissionService> request);
- // Called by a PermissionService identified as |service| when it has a
+ // Called by a mojom::PermissionService identified as |service| when it has a
// connection error in order to get unregistered and killed.
void ServiceHadConnectionError(PermissionServiceImpl* service);
« no previous file with comments | « content/browser/mojo_shell_browsertest.cc ('k') | content/browser/permissions/permission_service_context.cc » ('j') | no next file with comments »
@@ -12,24 +12,28 @@
class RenderProcessHost;
// Provides information to a PermissionService. It is used by the
-// PermissionService to handle request permission UI.
+// mojom::PermissionService to handle request permission UI.
// There is one PermissionServiceContext per RenderFrameHost/RenderProcessHost
@@ -12,24 +12,28 @@
// There is one PermissionServiceContext per RenderFrameHost/RenderProcessHost
-// which owns it. It then owns all PermissionService associated to their owner.
+// which owns it. It then owns all mojom::PermissionService associated to their
+// owner.
class PermissionServiceContext : public WebContentsObserver {
public:

Powered by Google App Engine
This is Rietveld 408576698